@@ -1,5 +1,6 @@
 from .utils import (change_dir, file_read, file_write, make_list, run_process,
-                    expand_directories)
+                    expand_directories, has_extension)
 from .flight_scripts import run_postflight_script, run_preflight_script
-from .filter import *  # pylint: disable=W0401
+from .filter import *  # pylint: disable=wildcard-import
+from .constants import *  # pylint: disable=wildcard-import
 from .main import PandocStyles
